@@ -37,8 +37,7 @@ GrantleeKi18nLocalizer::~GrantleeKi18nLocalizer()
 {
 }
 
-QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr,
-        const QVariantList &arguments) const
+QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, const QVariantList &arguments) const
 {
     KLocalizedString str = kstr;
     for (auto iter = arguments.cbegin(), end = arguments.cend(); iter != end; ++iter) {
@@ -94,15 +93,13 @@ QString GrantleeKi18nLocalizer::localizeString(const QString &string, const QVar
     return processArguments(str, arguments);
 }
 
-QString GrantleeKi18nLocalizer::localizePluralContextString(const QString &string, const QString &pluralForm,
-        const QString &context, const QVariantList &arguments) const
+QString GrantleeKi18nLocalizer::localizePluralContextString(const QString &string, const QString &pluralForm, const QString &context, const QVariantList &arguments) const
 {
     const KLocalizedString str = kxi18ncp(qPrintable(context), qPrintable(string), qPrintable(pluralForm));
     return processArguments(str, arguments);
 }
 
-QString GrantleeKi18nLocalizer::localizePluralString(const QString &string, const QString &pluralForm,
-        const QVariantList &arguments) const
+QString GrantleeKi18nLocalizer::localizePluralString(const QString &string, const QString &pluralForm, const QVariantList &arguments) const
 {
     const KLocalizedString str = kxi18np(qPrintable(string), qPrintable(pluralForm));
     return processArguments(str, arguments);
